Struct gdnative_network::MultiplayerPeerGDNative [−][src]
pub struct MultiplayerPeerGDNative { /* fields omitted */ }core class MultiplayerPeerGDNative inherits NetworkedMultiplayerPeer (reference counted).
Official documentation
See the documentation of this class in the Godot engine's official documentation.
Memory management
The lifetime of this object is automatically managed through reference counting.
Feature flag
This type is behind the gdnative crate's network feature flag.
Class hierarchy
MultiplayerPeerGDNative inherits methods from:
Methods
impl MultiplayerPeerGDNative[src]
impl MultiplayerPeerGDNativepub fn new() -> Self[src]
pub fn new() -> Selfpub fn new_ref(&self) -> Self[src]
pub fn new_ref(&self) -> SelfCreates a new reference to the same reference-counted object.
pub fn set_transfer_mode(&mut self, mode: i64)[src]
pub fn set_transfer_mode(&mut self, mode: i64)Inherited from NetworkedMultiplayerPeer.
pub fn get_transfer_mode(&self) -> NetworkedMultiplayerPeerTransferMode[src]
pub fn get_transfer_mode(&self) -> NetworkedMultiplayerPeerTransferModeInherited from NetworkedMultiplayerPeer.
pub fn set_target_peer(&mut self, id: i64)[src]
pub fn set_target_peer(&mut self, id: i64)Inherited from NetworkedMultiplayerPeer.
pub fn get_packet_peer(&self) -> i64[src]
pub fn get_packet_peer(&self) -> i64Inherited from NetworkedMultiplayerPeer.
pub fn poll(&mut self)[src]
pub fn poll(&mut self)Inherited from NetworkedMultiplayerPeer.
pub fn get_connection_status(&self) -> NetworkedMultiplayerPeerConnectionStatus[src]
pub fn get_connection_status(&self) -> NetworkedMultiplayerPeerConnectionStatusInherited from NetworkedMultiplayerPeer.
pub fn get_unique_id(&self) -> i64[src]
pub fn get_unique_id(&self) -> i64Inherited from NetworkedMultiplayerPeer.
pub fn set_refuse_new_connections(&mut self, enable: bool)[src]
pub fn set_refuse_new_connections(&mut self, enable: bool)Inherited from NetworkedMultiplayerPeer.
pub fn is_refusing_new_connections(&self) -> bool[src]
pub fn is_refusing_new_connections(&self) -> boolInherited from NetworkedMultiplayerPeer.
pub fn get_var(&mut self) -> Variant[src]
pub fn get_var(&mut self) -> VariantInherited from PacketPeer.
pub fn put_var(&mut self, var: Variant) -> GodotResult[src]
pub fn put_var(&mut self, var: Variant) -> GodotResultInherited from PacketPeer.
pub fn get_packet(&mut self) -> ByteArray[src]
pub fn get_packet(&mut self) -> ByteArrayInherited from PacketPeer.
pub fn put_packet(&mut self, buffer: ByteArray) -> GodotResult[src]
pub fn put_packet(&mut self, buffer: ByteArray) -> GodotResultInherited from PacketPeer.
pub fn get_packet_error(&self) -> GodotResult[src]
pub fn get_packet_error(&self) -> GodotResultInherited from PacketPeer.
pub fn get_available_packet_count(&self) -> i64[src]
pub fn get_available_packet_count(&self) -> i64Inherited from PacketPeer.
pub fn set_allow_object_decoding(&mut self, enable: bool)[src]
pub fn set_allow_object_decoding(&mut self, enable: bool)Inherited from PacketPeer.
pub fn is_object_decoding_allowed(&self) -> bool[src]
pub fn is_object_decoding_allowed(&self) -> boolInherited from PacketPeer.
pub fn init_ref(&mut self) -> bool[src]
pub fn init_ref(&mut self) -> boolInherited from Reference.
pub fn _notification(&mut self, what: i64)[src]
pub fn _notification(&mut self, what: i64)Inherited from Object.
pub fn _set(&mut self, property: GodotString, value: Variant) -> bool[src]
pub fn _set(&mut self, property: GodotString, value: Variant) -> boolInherited from Object.
pub fn _get(&mut self, property: GodotString) -> Variant[src]
pub fn _get(&mut self, property: GodotString) -> VariantInherited from Object.
pub fn _get_property_list(&mut self) -> VariantArray[src]
pub fn _get_property_list(&mut self) -> VariantArrayInherited from Object.
pub fn _init(&mut self)[src]
pub fn _init(&mut self)Inherited from Object.
pub fn get_class(&self) -> GodotString[src]
pub fn get_class(&self) -> GodotStringInherited from Object.
pub fn is_class(&self, _type: GodotString) -> bool[src]
pub fn is_class(&self, _type: GodotString) -> boolInherited from Object.
pub fn set(&mut self, property: GodotString, value: Variant)[src]
pub fn set(&mut self, property: GodotString, value: Variant)Inherited from Object.
pub fn get(&self, property: GodotString) -> Variant[src]
pub fn get(&self, property: GodotString) -> VariantInherited from Object.
pub fn set_indexed(&mut self, property: NodePath, value: Variant)[src]
pub fn set_indexed(&mut self, property: NodePath, value: Variant)Inherited from Object.
pub fn get_indexed(&self, property: NodePath) -> Variant[src]
pub fn get_indexed(&self, property: NodePath) -> VariantInherited from Object.
pub fn get_property_list(&self) -> VariantArray[src]
pub fn get_property_list(&self) -> VariantArrayInherited from Object.
pub fn get_method_list(&self) -> VariantArray[src]
pub fn get_method_list(&self) -> VariantArrayInherited from Object.
pub fn notification(&mut self, what: i64, reversed: bool)[src]
pub fn notification(&mut self, what: i64, reversed: bool)Inherited from Object.
pub fn get_instance_id(&self) -> i64[src]
pub fn get_instance_id(&self) -> i64Inherited from Object.
pub fn set_script(&mut self, script: Option<Reference>)[src]
pub fn set_script(&mut self, script: Option<Reference>)Inherited from Object.
pub fn get_script(&self) -> Option<Reference>[src]
pub fn get_script(&self) -> Option<Reference>Inherited from Object.
pub fn set_meta(&mut self, name: GodotString, value: Variant)[src]
pub fn set_meta(&mut self, name: GodotString, value: Variant)Inherited from Object.
pub fn get_meta(&self, name: GodotString) -> Variant[src]
pub fn get_meta(&self, name: GodotString) -> VariantInherited from Object.
pub fn has_meta(&self, name: GodotString) -> bool[src]
pub fn has_meta(&self, name: GodotString) -> boolInherited from Object.
pub fn get_meta_list(&self) -> StringArray[src]
pub fn get_meta_list(&self) -> StringArrayInherited from Object.
pub fn add_user_signal(&mut self, signal: GodotString, arguments: VariantArray)[src]
pub fn add_user_signal(&mut self, signal: GodotString, arguments: VariantArray)Inherited from Object.
pub fn has_user_signal(&self, signal: GodotString) -> bool[src]
pub fn has_user_signal(&self, signal: GodotString) -> boolInherited from Object.
pub fn emit_signal(
&mut self,
signal: GodotString,
varargs: &[Variant]
) -> Variant[src]
pub fn emit_signal(
&mut self,
signal: GodotString,
varargs: &[Variant]
) -> VariantInherited from Object.
pub fn call(&mut self, method: GodotString, varargs: &[Variant]) -> Variant[src]
pub fn call(&mut self, method: GodotString, varargs: &[Variant]) -> VariantInherited from Object.
pub fn call_deferred(
&mut self,
method: GodotString,
varargs: &[Variant]
) -> Variant[src]
pub fn call_deferred(
&mut self,
method: GodotString,
varargs: &[Variant]
) -> VariantInherited from Object.
pub fn callv(&mut self, method: GodotString, arg_array: VariantArray) -> Variant[src]
pub fn callv(&mut self, method: GodotString, arg_array: VariantArray) -> VariantInherited from Object.
pub fn has_method(&self, method: GodotString) -> bool[src]
pub fn has_method(&self, method: GodotString) -> boolInherited from Object.
pub fn get_signal_list(&self) -> VariantArray[src]
pub fn get_signal_list(&self) -> VariantArrayInherited from Object.
pub fn get_signal_connection_list(&self, signal: GodotString) -> VariantArray[src]
pub fn get_signal_connection_list(&self, signal: GodotString) -> VariantArrayInherited from Object.
pub fn get_incoming_connections(&self) -> VariantArray[src]
pub fn get_incoming_connections(&self) -> VariantArrayInherited from Object.
pub fn connect(
&mut self,
signal: GodotString,
target: Option<Object>,
method: GodotString,
binds: VariantArray,
flags: i64
) -> GodotResult[src]
pub fn connect(
&mut self,
signal: GodotString,
target: Option<Object>,
method: GodotString,
binds: VariantArray,
flags: i64
) -> GodotResultInherited from Object.
pub fn disconnect(
&mut self,
signal: GodotString,
target: Option<Object>,
method: GodotString
)[src]
pub fn disconnect(
&mut self,
signal: GodotString,
target: Option<Object>,
method: GodotString
)Inherited from Object.
pub fn is_connected(
&self,
signal: GodotString,
target: Option<Object>,
method: GodotString
) -> bool[src]
pub fn is_connected(
&self,
signal: GodotString,
target: Option<Object>,
method: GodotString
) -> boolInherited from Object.
pub fn set_block_signals(&mut self, enable: bool)[src]
pub fn set_block_signals(&mut self, enable: bool)Inherited from Object.
pub fn is_blocking_signals(&self) -> bool[src]
pub fn is_blocking_signals(&self) -> boolInherited from Object.
pub fn property_list_changed_notify(&mut self)[src]
pub fn property_list_changed_notify(&mut self)Inherited from Object.
pub fn set_message_translation(&mut self, enable: bool)[src]
pub fn set_message_translation(&mut self, enable: bool)Inherited from Object.
pub fn can_translate_messages(&self) -> bool[src]
pub fn can_translate_messages(&self) -> boolInherited from Object.
pub fn tr(&self, message: GodotString) -> GodotString[src]
pub fn tr(&self, message: GodotString) -> GodotStringInherited from Object.
pub fn is_queued_for_deletion(&self) -> bool[src]
pub fn is_queued_for_deletion(&self) -> boolInherited from Object.
pub fn to_networked_multiplayer_peer(&self) -> NetworkedMultiplayerPeer[src]
pub fn to_networked_multiplayer_peer(&self) -> NetworkedMultiplayerPeerUp-cast.
pub fn to_packet_peer(&self) -> PacketPeer[src]
pub fn to_packet_peer(&self) -> PacketPeerUp-cast.
pub fn to_reference(&self) -> Reference[src]
pub fn to_reference(&self) -> ReferenceUp-cast.
pub fn to_object(&self) -> Object[src]
pub fn to_object(&self) -> ObjectUp-cast.
pub fn cast<T: GodotObject>(&self) -> Option<T>[src]
pub fn cast<T: GodotObject>(&self) -> Option<T>Generic dynamic cast.