Struct gdnative_network::StreamPeer[][src]

pub struct StreamPeer { /* fields omitted */ }

core class StreamPeer inherits Reference (reference counted).

Official documentation

See the documentation of this class in the Godot engine's official documentation.

Memory management

The lifetime of this object is automatically managed through reference counting.

Feature flag

This type is behind the gdnative crate's network feature flag.

Class hierarchy

StreamPeer inherits methods from:

Methods

impl StreamPeer
[src]

Inherited from Reference.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Inherited from Object.

Up-cast.

Up-cast.

Generic dynamic cast.