Struct gdnative_network::StreamPeerBuffer [−][src]
pub struct StreamPeerBuffer { /* fields omitted */ }core class StreamPeerBuffer inherits StreamPeer (reference counted).
Official documentation
See the documentation of this class in the Godot engine's official documentation.
Memory management
The lifetime of this object is automatically managed through reference counting.
Feature flag
This type is behind the gdnative crate's network feature flag.
Class hierarchy
StreamPeerBuffer inherits methods from:
Methods
impl StreamPeerBuffer[src]
impl StreamPeerBufferpub fn new() -> Self[src]
pub fn new() -> Selfpub fn new_ref(&self) -> Self[src]
pub fn new_ref(&self) -> SelfCreates a new reference to the same reference-counted object.
pub fn seek(&mut self, position: i64)[src]
pub fn seek(&mut self, position: i64)pub fn get_size(&self) -> i64[src]
pub fn get_size(&self) -> i64pub fn get_position(&self) -> i64[src]
pub fn get_position(&self) -> i64pub fn resize(&mut self, size: i64)[src]
pub fn resize(&mut self, size: i64)pub fn set_data_array(&mut self, data: ByteArray)[src]
pub fn set_data_array(&mut self, data: ByteArray)pub fn get_data_array(&self) -> ByteArray[src]
pub fn get_data_array(&self) -> ByteArraypub fn clear(&mut self)[src]
pub fn clear(&mut self)pub fn duplicate(&self) -> Option<StreamPeerBuffer>[src]
pub fn duplicate(&self) -> Option<StreamPeerBuffer>pub fn put_data(&mut self, data: ByteArray) -> GodotResult[src]
pub fn put_data(&mut self, data: ByteArray) -> GodotResultInherited from StreamPeer.
pub fn put_partial_data(&mut self, data: ByteArray) -> VariantArray[src]
pub fn put_partial_data(&mut self, data: ByteArray) -> VariantArrayInherited from StreamPeer.
pub fn get_data(&mut self, bytes: i64) -> VariantArray[src]
pub fn get_data(&mut self, bytes: i64) -> VariantArrayInherited from StreamPeer.
pub fn get_partial_data(&mut self, bytes: i64) -> VariantArray[src]
pub fn get_partial_data(&mut self, bytes: i64) -> VariantArrayInherited from StreamPeer.
pub fn get_available_bytes(&self) -> i64[src]
pub fn get_available_bytes(&self) -> i64Inherited from StreamPeer.
pub fn set_big_endian(&mut self, enable: bool)[src]
pub fn set_big_endian(&mut self, enable: bool)Inherited from StreamPeer.
pub fn is_big_endian_enabled(&self) -> bool[src]
pub fn is_big_endian_enabled(&self) -> boolInherited from StreamPeer.
pub fn put_8(&mut self, value: i64)[src]
pub fn put_8(&mut self, value: i64)Inherited from StreamPeer.
pub fn put_u8(&mut self, value: i64)[src]
pub fn put_u8(&mut self, value: i64)Inherited from StreamPeer.
pub fn put_16(&mut self, value: i64)[src]
pub fn put_16(&mut self, value: i64)Inherited from StreamPeer.
pub fn put_u16(&mut self, value: i64)[src]
pub fn put_u16(&mut self, value: i64)Inherited from StreamPeer.
pub fn put_32(&mut self, value: i64)[src]
pub fn put_32(&mut self, value: i64)Inherited from StreamPeer.
pub fn put_u32(&mut self, value: i64)[src]
pub fn put_u32(&mut self, value: i64)Inherited from StreamPeer.
pub fn put_64(&mut self, value: i64)[src]
pub fn put_64(&mut self, value: i64)Inherited from StreamPeer.
pub fn put_u64(&mut self, value: i64)[src]
pub fn put_u64(&mut self, value: i64)Inherited from StreamPeer.
pub fn put_float(&mut self, value: f64)[src]
pub fn put_float(&mut self, value: f64)Inherited from StreamPeer.
pub fn put_double(&mut self, value: f64)[src]
pub fn put_double(&mut self, value: f64)Inherited from StreamPeer.
pub fn put_utf8_string(&mut self, value: GodotString)[src]
pub fn put_utf8_string(&mut self, value: GodotString)Inherited from StreamPeer.
pub fn put_var(&mut self, value: Variant)[src]
pub fn put_var(&mut self, value: Variant)Inherited from StreamPeer.
pub fn get_8(&mut self) -> i64[src]
pub fn get_8(&mut self) -> i64Inherited from StreamPeer.
pub fn get_u8(&mut self) -> i64[src]
pub fn get_u8(&mut self) -> i64Inherited from StreamPeer.
pub fn get_16(&mut self) -> i64[src]
pub fn get_16(&mut self) -> i64Inherited from StreamPeer.
pub fn get_u16(&mut self) -> i64[src]
pub fn get_u16(&mut self) -> i64Inherited from StreamPeer.
pub fn get_32(&mut self) -> i64[src]
pub fn get_32(&mut self) -> i64Inherited from StreamPeer.
pub fn get_u32(&mut self) -> i64[src]
pub fn get_u32(&mut self) -> i64Inherited from StreamPeer.
pub fn get_64(&mut self) -> i64[src]
pub fn get_64(&mut self) -> i64Inherited from StreamPeer.
pub fn get_u64(&mut self) -> i64[src]
pub fn get_u64(&mut self) -> i64Inherited from StreamPeer.
pub fn get_float(&mut self) -> f64[src]
pub fn get_float(&mut self) -> f64Inherited from StreamPeer.
pub fn get_double(&mut self) -> f64[src]
pub fn get_double(&mut self) -> f64Inherited from StreamPeer.
pub fn get_string(&mut self, bytes: i64) -> GodotString[src]
pub fn get_string(&mut self, bytes: i64) -> GodotStringInherited from StreamPeer.
pub fn get_utf8_string(&mut self, bytes: i64) -> GodotString[src]
pub fn get_utf8_string(&mut self, bytes: i64) -> GodotStringInherited from StreamPeer.
pub fn get_var(&mut self) -> Variant[src]
pub fn get_var(&mut self) -> VariantInherited from StreamPeer.
pub fn init_ref(&mut self) -> bool[src]
pub fn init_ref(&mut self) -> boolInherited from Reference.
pub fn _notification(&mut self, what: i64)[src]
pub fn _notification(&mut self, what: i64)Inherited from Object.
pub fn _set(&mut self, property: GodotString, value: Variant) -> bool[src]
pub fn _set(&mut self, property: GodotString, value: Variant) -> boolInherited from Object.
pub fn _get(&mut self, property: GodotString) -> Variant[src]
pub fn _get(&mut self, property: GodotString) -> VariantInherited from Object.
pub fn _get_property_list(&mut self) -> VariantArray[src]
pub fn _get_property_list(&mut self) -> VariantArrayInherited from Object.
pub fn _init(&mut self)[src]
pub fn _init(&mut self)Inherited from Object.
pub fn get_class(&self) -> GodotString[src]
pub fn get_class(&self) -> GodotStringInherited from Object.
pub fn is_class(&self, _type: GodotString) -> bool[src]
pub fn is_class(&self, _type: GodotString) -> boolInherited from Object.
pub fn set(&mut self, property: GodotString, value: Variant)[src]
pub fn set(&mut self, property: GodotString, value: Variant)Inherited from Object.
pub fn get(&self, property: GodotString) -> Variant[src]
pub fn get(&self, property: GodotString) -> VariantInherited from Object.
pub fn set_indexed(&mut self, property: NodePath, value: Variant)[src]
pub fn set_indexed(&mut self, property: NodePath, value: Variant)Inherited from Object.
pub fn get_indexed(&self, property: NodePath) -> Variant[src]
pub fn get_indexed(&self, property: NodePath) -> VariantInherited from Object.
pub fn get_property_list(&self) -> VariantArray[src]
pub fn get_property_list(&self) -> VariantArrayInherited from Object.
pub fn get_method_list(&self) -> VariantArray[src]
pub fn get_method_list(&self) -> VariantArrayInherited from Object.
pub fn notification(&mut self, what: i64, reversed: bool)[src]
pub fn notification(&mut self, what: i64, reversed: bool)Inherited from Object.
pub fn get_instance_id(&self) -> i64[src]
pub fn get_instance_id(&self) -> i64Inherited from Object.
pub fn set_script(&mut self, script: Option<Reference>)[src]
pub fn set_script(&mut self, script: Option<Reference>)Inherited from Object.
pub fn get_script(&self) -> Option<Reference>[src]
pub fn get_script(&self) -> Option<Reference>Inherited from Object.
pub fn set_meta(&mut self, name: GodotString, value: Variant)[src]
pub fn set_meta(&mut self, name: GodotString, value: Variant)Inherited from Object.
pub fn get_meta(&self, name: GodotString) -> Variant[src]
pub fn get_meta(&self, name: GodotString) -> VariantInherited from Object.
pub fn has_meta(&self, name: GodotString) -> bool[src]
pub fn has_meta(&self, name: GodotString) -> boolInherited from Object.
pub fn get_meta_list(&self) -> StringArray[src]
pub fn get_meta_list(&self) -> StringArrayInherited from Object.
pub fn add_user_signal(&mut self, signal: GodotString, arguments: VariantArray)[src]
pub fn add_user_signal(&mut self, signal: GodotString, arguments: VariantArray)Inherited from Object.
pub fn has_user_signal(&self, signal: GodotString) -> bool[src]
pub fn has_user_signal(&self, signal: GodotString) -> boolInherited from Object.
pub fn emit_signal(
&mut self,
signal: GodotString,
varargs: &[Variant]
) -> Variant[src]
pub fn emit_signal(
&mut self,
signal: GodotString,
varargs: &[Variant]
) -> VariantInherited from Object.
pub fn call(&mut self, method: GodotString, varargs: &[Variant]) -> Variant[src]
pub fn call(&mut self, method: GodotString, varargs: &[Variant]) -> VariantInherited from Object.
pub fn call_deferred(
&mut self,
method: GodotString,
varargs: &[Variant]
) -> Variant[src]
pub fn call_deferred(
&mut self,
method: GodotString,
varargs: &[Variant]
) -> VariantInherited from Object.
pub fn callv(&mut self, method: GodotString, arg_array: VariantArray) -> Variant[src]
pub fn callv(&mut self, method: GodotString, arg_array: VariantArray) -> VariantInherited from Object.
pub fn has_method(&self, method: GodotString) -> bool[src]
pub fn has_method(&self, method: GodotString) -> boolInherited from Object.
pub fn get_signal_list(&self) -> VariantArray[src]
pub fn get_signal_list(&self) -> VariantArrayInherited from Object.
pub fn get_signal_connection_list(&self, signal: GodotString) -> VariantArray[src]
pub fn get_signal_connection_list(&self, signal: GodotString) -> VariantArrayInherited from Object.
pub fn get_incoming_connections(&self) -> VariantArray[src]
pub fn get_incoming_connections(&self) -> VariantArrayInherited from Object.
pub fn connect(
&mut self,
signal: GodotString,
target: Option<Object>,
method: GodotString,
binds: VariantArray,
flags: i64
) -> GodotResult[src]
pub fn connect(
&mut self,
signal: GodotString,
target: Option<Object>,
method: GodotString,
binds: VariantArray,
flags: i64
) -> GodotResultInherited from Object.
pub fn disconnect(
&mut self,
signal: GodotString,
target: Option<Object>,
method: GodotString
)[src]
pub fn disconnect(
&mut self,
signal: GodotString,
target: Option<Object>,
method: GodotString
)Inherited from Object.
pub fn is_connected(
&self,
signal: GodotString,
target: Option<Object>,
method: GodotString
) -> bool[src]
pub fn is_connected(
&self,
signal: GodotString,
target: Option<Object>,
method: GodotString
) -> boolInherited from Object.
pub fn set_block_signals(&mut self, enable: bool)[src]
pub fn set_block_signals(&mut self, enable: bool)Inherited from Object.
pub fn is_blocking_signals(&self) -> bool[src]
pub fn is_blocking_signals(&self) -> boolInherited from Object.
pub fn property_list_changed_notify(&mut self)[src]
pub fn property_list_changed_notify(&mut self)Inherited from Object.
pub fn set_message_translation(&mut self, enable: bool)[src]
pub fn set_message_translation(&mut self, enable: bool)Inherited from Object.
pub fn can_translate_messages(&self) -> bool[src]
pub fn can_translate_messages(&self) -> boolInherited from Object.
pub fn tr(&self, message: GodotString) -> GodotString[src]
pub fn tr(&self, message: GodotString) -> GodotStringInherited from Object.
pub fn is_queued_for_deletion(&self) -> bool[src]
pub fn is_queued_for_deletion(&self) -> boolInherited from Object.
pub fn to_stream_peer(&self) -> StreamPeer[src]
pub fn to_stream_peer(&self) -> StreamPeerUp-cast.
pub fn to_reference(&self) -> Reference[src]
pub fn to_reference(&self) -> ReferenceUp-cast.
pub fn to_object(&self) -> Object[src]
pub fn to_object(&self) -> ObjectUp-cast.
pub fn cast<T: GodotObject>(&self) -> Option<T>[src]
pub fn cast<T: GodotObject>(&self) -> Option<T>Generic dynamic cast.